@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+import importlib
+
 import discord.errors
 import traceback
 import abc
@@ -8,11 +10,17 @@ from .config import Config
 from .context import MessageContext
 from .errors import *
 from .response import Response
+import aiohttp
 from . import utils
 import asyncio as aio
 from . import argh
 import re
+import discord.ext
 from aurcore.event import *
+import inspect
+import logging
+
+logging.getLogger("discord.client").addFilter(lambda r: r.getMessage() != "PyNaCl is not installed, voice will NOT be supported")
 
 if ty.TYPE_CHECKING:
     import discord
@@ -29,13 +37,26 @@ class AurfluxCog:
     def __init__(self, aurflux: Aurflux):
         self.aurflux = aurflux
         self.router = EventRouter(self.__class__.__name__, self.aurflux.router)
+        self.listeners: ty.Dict[ty.Union[EventFunction, EventRouter, EventWaiter], EventMuxer] = {}
         self.route()
 
     async def startup(self):
         pass
 
+    def register(self, listener_tup: ty.Tuple[EventMuxer, ty.Union[EventFunction, EventRouter, EventWaiter]]):
+        muxer, listener = listener_tup
+        self.listeners[listener] = muxer
+
+    def teardown(self):
+        for listener, muxer in self.listeners.items():
+            if isinstance(listener, EventRouter):
+                muxer.router = None
+            else:
+                muxer.remove_listener(listener)
+
     @abc.abstractmethod
-    def route(self): ...
+    def route(self):
+        ...
 
 
 def __aiterify(obj: ty.Union[ty.Coroutine, ty.AsyncIterable]):
@@ -74,9 +95,8 @@ def register_builtins(aurflux: Aurflux):
         try:
             if cmd not in aurflux.commands:
                 return
-            async with ctx.channel.typing():
-                async for response in __aiterify(aurflux.commands[cmd].execute(ctx)):
-                    await response.execute(ctx)
+            async for response in __aiterify(aurflux.commands[cmd].execute(ctx)):
+                await response.execute(ctx)
         except CommandError as e:
             info_message = f"{e}"
             if argparser := aurflux.commands[cmd].argparser:
@@ -88,11 +108,23 @@ def register_builtins(aurflux: Aurflux):
                 info_message += f"\n```{argparser.format_help()}```"
             await Response(content=info_message).execute(ctx)
 
+    @CommandCheck.check(lambda ctx: ctx.author.id == aurflux.admin_id)
+    @aurflux.commandeer(name="reload", parsed=False, private=True)
+    async def reload(ctx: MessageContext, cog_name: str):
+        reloaded_cogs = []
+        for cog in aurflux.cogs:
+            new_cog = cog
+            if cog.__class__.__name__.lower() == cog_name:
+                module = importlib.reload(inspect.getmodule(cog))
+                new_cog = getattr(module, cog.__class__.__name__)(ctx.aurflux)
+            reloaded_cogs.append(new_cog)
+        ctx.aurflux.cogs = reloaded_cogs
+
     @CommandCheck.check(lambda ctx: ctx.author.id == aurflux.admin_id)
     @aurflux.commandeer(name="exec", parsed=False, private=True)
     async def exec_(ctx: MessageContext, script: str):
         exec_func = utils.sexec
-        if any(line.strip().startswith("await") for line in script.split("\n")):
+        if "await " in script:
             exec_func = utils.aexec
 
         with utils.Timer() as t:
@@ -148,10 +180,11 @@ class Aurflux(discord.Client):
         self.admin_id = admin_id
         register_builtins(self)
         self.cogs: ty.List[AurfluxCog] = []
+        self.aiohttp_session = aiohttp.ClientSession()
 
     def commandeer(self, name: ty.Optional[str] = None, parsed: bool = True, private: bool = False) -> ty.Callable[[ty.Callable[[...], ty.Awaitable[Response]]], Command]:
         def command_deco(func: ty.Callable[[...], ty.Awaitable[Response]]) -> Command:
-            cmd = Command(client=self, func=func, name=(name or func.__name__), parsed=parsed, private=private)
+            cmd = Command(aurflux=self, func=func, name=(name or func.__name__), parsed=parsed, private=private)
             if cmd.name in self.commands:
                 raise TypeError(f"Attempting to register command {cmd} when {self.commands[cmd.name]} already exists")
             self.commands[cmd.name] = cmd
@@ -167,5 +200,5 @@ class Aurflux(discord.Client):
         self.cogs.append(cog(self))
 
     async def startup(self, token, *args, **kwargs):
-        await self.start(token, *args, **kwargs)
         await aio.gather(*[cog.startup() for cog in self.cogs])
+        await self.start(token, *args, **kwargs)
